@@ -47,12 +47,12 @@ class GlancesAmp(object):
     EMAIL = '?'
 
     def __init__(self, name=None, args=None):
-        """Init AMP classe."""
+        """Init AMP class."""
         logger.debug("AMP - Init {} version {}".format(self.NAME, self.VERSION))
 
         # AMP name (= module name without glances_)
         if name is None:
-            self.amp_name = self.__class__.__module__[len('glances_'):]
+            self.amp_name = self.__class__.__module__[len('glances_') :]
         else:
             self.amp_name = name
 
@@ -69,7 +69,7 @@ class GlancesAmp(object):
     def load_config(self, config):
         """Load AMP parameters from the configuration file."""
 
-        # Read AMP confifuration.
+        # Read AMP configuration.
         # For ex, the AMP foo should have the following section:
         #
         # [foo]
@@ -77,15 +77,13 @@ class GlancesAmp(object):
         # regex=\/usr\/bin\/nginx
         # refresh=60
         #
-        # and optionnaly:
+        # and optionally:
         #
         # one_line=false
         # option1=opt1
-        # ...
-        #
+
         amp_section = 'amp_' + self.amp_name
-        if (hasattr(config, 'has_section') and
-                config.has_section(amp_section)):
+        if hasattr(config, 'has_section') and config.has_section(amp_section):
             logger.debug("AMP - {}: Load configuration".format(self.NAME))
             for param, _ in config.items(amp_section):
                 try:
@@ -103,7 +101,11 @@ class GlancesAmp(object):
             # Refresh option is mandatory
             for k in ['refresh']:
                 if k not in self.configs:
-                    logger.warning("AMP - {}: Can not find configuration key {} in section {} (the AMP will be disabled)".format(self.NAME, k, self.amp_name))
+                    logger.warning(
+                        "AMP - {}: Can not find configuration key {} in section {} (the AMP will be disabled)".format(
+                            self.NAME, k, self.amp_name
+                        )
+                    )
                     self.configs['enable'] = 'false'
         else:
             logger.debug("AMP - {} is disabled".format(self.NAME))
@@ -137,7 +139,7 @@ class GlancesAmp(object):
         return self.get('refresh')
 
     def one_line(self):
-        """Return True|False if the AMP shoukd be displayed in oneline (one_lineline=true|false)."""
+        """Return True|False if the AMP should be displayed in one line (one_line=true|false)."""
         ret = self.get('one_line')
         if ret is None:
             return False
@@ -149,7 +151,9 @@ class GlancesAmp(object):
         return self.timer.get()
 
     def should_update(self):
-        """Return True is the AMP should be updated:
+        """Return True is the AMP should be updated
+
+        Conditions for update:
         - AMP is enable
         - only update every 'refresh' seconds
         """
@@ -177,7 +181,8 @@ class GlancesAmp(object):
 
     def set_result(self, result, separator=''):
         """Store the result (string) into the result key of the AMP
-        if one_line is true then replace \n by separator
+
+        If one_line is true then it replaces `\n` by the separator
         """
         if self.one_line():
             self.configs['result'] = u(result).replace('\n', separator)
@@ -185,7 +190,7 @@ class GlancesAmp(object):
             self.configs['result'] = u(result)
 
     def result(self):
-        """ Return the result of the AMP (as a string)"""
+        """Return the result of the AMP (as a string)"""
         ret = self.get('result')
         if ret is not None:
             ret = u(ret)
