@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2018 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -22,12 +22,14 @@
 import json
 import socket
 import sys
+import time
 
 from glances import __version__
 from glances.compat import Fault, ProtocolError, ServerProxy, Transport
 from glances.logger import logger
 from glances.stats_client import GlancesStatsClient
 from glances.outputs.glances_curses import GlancesCursesClient
+from glances.timer import Counter
 
 
 class GlancesClientTransport(Transport):
@@ -46,8 +48,9 @@ class GlancesClient(object):
         # Store the arg/config
         self.args = args
         self.config = config
-        # Quiet mode
+
         self._quiet = args.quiet
+        self.refresh_time = args.time
 
         # Default client mode
         self._client_mode = 'glances'
@@ -57,8 +60,7 @@ class GlancesClient(object):
 
         # Build the URI
         if args.password != "":
-            self.uri = 'http://{}:{}@{}:{}'.format(args.username, args.password,
-                                                   args.client, args.port)
+            self.uri = 'http://{}:{}@{}:{}'.format(args.username, args.password, args.client, args.port)
         else:
             self.uri = 'http://{}:{}'.format(args.client, args.port)
         logger.debug("Try to connect to {}".format(self.uri))
@@ -107,11 +109,11 @@ class GlancesClient(object):
             # Fallback to SNMP
             self.client_mode = 'snmp'
             logger.error("Connection to Glances server failed ({} {})".format(err.errno, err.strerror))
-            fallbackmsg = 'No Glances server found on {}. Trying fallback to SNMP...'.format(self.uri)
+            fall_back_msg = 'No Glances server found on {}. Trying fallback to SNMP...'.format(self.uri)
             if not self.return_to_browser:
-                print(fallbackmsg)
+                print(fall_back_msg)
             else:
-                logger.info(fallbackmsg)
+                logger.info(fall_back_msg)
         except ProtocolError as err:
             # Other errors
             msg = "Connection to server {} failed".format(self.uri)
@@ -130,8 +132,12 @@ class GlancesClient(object):
                 self.stats.set_plugins(json.loads(self.client.getAllPlugins()))
                 logger.debug("Client version: {} / Server version: {}".format(__version__, client_version))
             else:
-                self.log_and_exit(('Client and server not compatible: '
-                                   'Client version: {} / Server version: {}'.format(__version__, client_version)))
+                self.log_and_exit(
+                    (
+                        'Client and server not compatible: '
+                        'Client version: {} / Server version: {}'.format(__version__, client_version)
+                    )
+                )
                 return False
 
         return True
@@ -240,20 +246,34 @@ class GlancesClient(object):
             self.end()
             return self.client_mode
 
-        exitkey = False
+        exit_key = False
         try:
-            while True and not exitkey:
+            while True and not exit_key:
                 # Update the stats
+                counter = Counter()
                 cs_status = self.update()
+                logger.debug('Stats updated duration: {} seconds'.format(counter.get()))
+
+                # Export stats using export modules
+                counter_export = Counter()
+                self.stats.export(self.stats)
+                logger.debug('Stats exported duration: {} seconds'.format(counter_export.get()))
+
+                # Patch for issue1326 to avoid < 0 refresh
+                adapted_refresh = self.refresh_time - counter.get()
+                adapted_refresh = adapted_refresh if adapted_refresh > 0 else 0
 
                 # Update the screen
                 if not self.quiet:
-                    exitkey = self.screen.update(self.stats,
-                                                 cs_status=cs_status,
-                                                 return_to_browser=self.return_to_browser)
-
-                # Export stats using export modules
-                self.stats.export(self.stats)
+                    exit_key = self.screen.update(
+                        self.stats,
+                        duration=adapted_refresh,
+                        cs_status=cs_status,
+                        return_to_browser=self.return_to_browser,
+                    )
+                else:
+                    # In quiet mode, we only wait adapated_refresh seconds
+                    time.sleep(adapted_refresh)
         except Exception as e:
             logger.critical(e)
             self.end()
