@@ -37,7 +37,7 @@ class Export(GlancesExport):
         """Init the OpenTSDB export IF."""
         super(Export, self).__init__(config=config, args=args)
 
-        # Mandatories configuration keys (additional to host and port)
+        # Mandatory configuration keys (additional to host and port)
         # N/A
 
         # Optionals configuration keys
@@ -45,9 +45,7 @@ class Export(GlancesExport):
         self.tags = None
 
         # Load the configuration file
-        self.export_enable = self.load_conf('opentsdb',
-                                            mandatories=['host', 'port'],
-                                            options=['prefix', 'tags'])
+        self.export_enable = self.load_conf('opentsdb', mandatories=['host', 'port'], options=['prefix', 'tags'])
         if not self.export_enable:
             sys.exit(2)
 
@@ -64,9 +62,7 @@ class Export(GlancesExport):
             return None
 
         try:
-            db = potsdb.Client(self.host,
-                               port=int(self.port),
-                               check_host=True)
+            db = potsdb.Client(self.host, port=int(self.port), check_host=True)
         except Exception as e:
             logger.critical("Cannot connect to OpenTSDB server %s:%s (%s)" % (self.host, self.port, e))
             sys.exit(2)
