@@ -24,45 +24,33 @@ from datetime import datetime
 from glances.logger import logger
 from glances.events import glances_events
 from glances.thresholds import glances_thresholds
+
 # from glances.logger import logger
 from glances.plugins.glances_plugin import GlancesPlugin
 
 # Static decision tree for the global alert message
 # - msg: Message to be displayed (result of the decision tree)
-# - threasholds: a list of stats to take into account
-# - thresholds_min: minimal value of the threasholds sum
+# - thresholds: a list of stats to take into account
+# - thresholds_min: minimal value of the thresholds sum
 # -                 0: OK
 # -                 1: CAREFUL
 # -                 2: WARNING
 # -                 3: CRITICAL
-tree = [{'msg': 'No warning or critical alert detected',
-         'thresholds': [],
-         'thresholds_min': 0},
-        {'msg': 'High CPU user mode',
-         'thresholds': ['cpu_user'],
-         'thresholds_min': 2},
-        {'msg': 'High CPU kernel usage',
-         'thresholds': ['cpu_system'],
-         'thresholds_min': 2},
-        {'msg': 'High CPU I/O waiting',
-         'thresholds': ['cpu_iowait'],
-         'thresholds_min': 2},
-        {'msg': 'Large CPU stolen time. System running the hypervisor is too busy.',
-         'thresholds': ['cpu_steal'],
-         'thresholds_min': 2},
-        {'msg': 'High CPU niced value',
-         'thresholds': ['cpu_niced'],
-         'thresholds_min': 2},
-        {'msg': 'System overloaded in the last 5 minutes',
-         'thresholds': ['load'],
-         'thresholds_min': 2},
-        {'msg': 'High swap (paging) usage',
-         'thresholds': ['memswap'],
-         'thresholds_min': 2},
-        {'msg': 'High memory consumption',
-         'thresholds': ['mem'],
-         'thresholds_min': 2},
-        ]
+tree = [
+    {'msg': 'No warning or critical alert detected', 'thresholds': [], 'thresholds_min': 0},
+    {'msg': 'High CPU user mode', 'thresholds': ['cpu_user'], 'thresholds_min': 2},
+    {'msg': 'High CPU kernel usage', 'thresholds': ['cpu_system'], 'thresholds_min': 2},
+    {'msg': 'High CPU I/O waiting', 'thresholds': ['cpu_iowait'], 'thresholds_min': 2},
+    {
+        'msg': 'Large CPU stolen time. System running the hypervisor is too busy.',
+        'thresholds': ['cpu_steal'],
+        'thresholds_min': 2,
+    },
+    {'msg': 'High CPU niced value', 'thresholds': ['cpu_niced'], 'thresholds_min': 2},
+    {'msg': 'System overloaded in the last 5 minutes', 'thresholds': ['load'], 'thresholds_min': 2},
+    {'msg': 'High swap (paging) usage', 'thresholds': ['memswap'], 'thresholds_min': 2},
+    {'msg': 'High memory consumption', 'thresholds': ['mem'], 'thresholds_min': 2},
+]
 
 # @TODO: change the algo to use the following decision tree
 # Source: Inspire by https://scoutapm.com/blog/slow_server_flow_chart
@@ -74,7 +62,7 @@ tree = [{'msg': 'No warning or critical alert detected',
 # - 2: WARNING
 # - 3: CRITICAL
 tree_new = {
-    'cpu_iowait':  {
+    'cpu_iowait': {
         '_yes': {
             'memswap': {
                 '_yes': {
@@ -84,13 +72,13 @@ tree_new = {
                             # business-as-usual or not. For example, a memory leak can be satisfactorily addressed by a one-time or periodic
                             # restart of the process.
                             # - if memory usage seems anomalous: kill the offending processes.
-                            # - if memory usage seems business-as-usual: add RAM to the server, or split high-memory using services to other servers.
+                            # - if memory usage seems business-as-usual: add RAM to the server, or split high-memory using services to other servers.
                             '_msg': "Memory issue"
                         },
                         '_no': {
                             # ???
                             '_msg': "Swap issue"
-                        }
+                        },
                     }
                 },
                 '_no': {
@@ -98,9 +86,9 @@ tree_new = {
                     # iotop is an awesome tool for identifying io offenders. Two things to note:
                     # unless you've already installed iotop, it's probably not already on your system.
                     # Recommendation: install it before you need it - - it's no fun trying to install a troubleshooting
-                    # tool on an overloaded machine (iotop requies a Linux of 2.62 or above)
+                    # tool on an overloaded machine (iotop requires a Linux of 2.62 or above)
                     '_msg': "I/O issue"
-                }
+                },
             }
         },
         '_no': {
@@ -108,9 +96,9 @@ tree_new = {
                 '_yes': {
                     'cpu_user': {
                         '_yes': {
-                            # We expect the usertime percentage to be high.
+                            # We expect the user-time percentage to be high.
                             # There's most likely a program or service you've configured on you server that's hogging CPU.
-                            # Checking the % user time just confirms this. When you see that the % usertime is high,
+                            # Checking the % user time just confirms this. When you see that the % user-time is high,
                             # it's time to see what executable is monopolizing the CPU
                             # Once you've confirmed that the % usertime is high, check the process list(also provided by top).
                             # Be default, top sorts the process list by % CPU, so you can just look at the top process or processes.
@@ -128,11 +116,9 @@ tree_new = {
                                 '_yes': {
                                     '_msg': "CPU issue with stolen time. System running the hypervisor may be too busy."
                                 },
-                                '_no': {
-                                    '_msg': "CPU issue with system process(es)"
-                                }
+                                '_no': {'_msg': "CPU issue with system process(es)"},
                             }
-                        }
+                        },
                     }
                 },
                 '_no': {
@@ -152,10 +138,10 @@ tree_new = {
                         # to(or being attempted to be read from) and lsof can give you a mapping of those file descriptors to
                         # network connections.
                         '_msg': "External issue"
-                    }
-                }
+                    },
+                },
             }
-        }
+        },
     }
 }
 
@@ -163,7 +149,7 @@ tree_new = {
 def global_message():
     """Parse the decision tree and return the message.
 
-    Note: message corresponding to the current threasholds values
+    Note: message corresponding to the current thresholds values
     """
     # Compute the weight for each item in the tree
     current_thresholds = glances_thresholds.get()
@@ -171,7 +157,7 @@ def global_message():
         i['weight'] = sum([current_thresholds[t].value() for t in i['thresholds'] if t in current_thresholds])
     themax = max(tree, key=lambda d: d['weight'])
     if themax['weight'] >= themax['thresholds_min']:
-        # Check if the weight is > to the minimal threashold value
+        # Check if the weight is > to the minimal threshold value
         return themax['msg']
     else:
         return tree[0]['msg']
@@ -185,9 +171,7 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None, config=None):
         """Init the plugin."""
-        super(Plugin, self).__init__(args=args,
-                                     config=config,
-                                     stats_init_value=[])
+        super(Plugin, self).__init__(args=args, config=config, stats_init_value=[])
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -226,8 +210,7 @@ class Plugin(GlancesPlugin):
             # Duration
             if alert[1] > 0:
                 # If finished display duration
-                msg = ' ({})'.format(datetime.fromtimestamp(alert[1]) -
-                                     datetime.fromtimestamp(alert[0]))
+                msg = ' ({})'.format(datetime.fromtimestamp(alert[1]) - datetime.fromtimestamp(alert[0]))
             else:
                 msg = ' (ongoing)'
             ret.append(self.curse_add_line(msg))
@@ -244,8 +227,7 @@ class Plugin(GlancesPlugin):
             if self.approx_equal(alert[6], alert[4], tolerance=0.1):
                 msg = ' ({:.1f})'.format(alert[5])
             else:
-                msg = ' (Min:{:.1f} Mean:{:.1f} Max:{:.1f})'.format(
-                    alert[6], alert[5], alert[4])
+                msg = ' (Min:{:.1f} Mean:{:.1f} Max:{:.1f})'.format(alert[6], alert[5], alert[4])
             ret.append(self.curse_add_line(msg))
             # Top processes
             top_process = ', '.join([p['name'] for p in alert[9]])
