@@ -36,15 +36,18 @@ except ImportError as e:
 else:
     import_error_tag = False
 
-# List of online services to retreive public IP address
+# List of online services to retrieve public IP address
 # List of tuple (url, json, key)
 # - url: URL of the Web site
 # - json: service return a JSON (True) or string (False)
-# - key: key of the IP addresse in the JSON structure
-urls = [('https://ip.42.pl/raw', False, None),
-        ('https://httpbin.org/ip', True, 'origin'),
-        ('https://jsonip.com', True, 'ip'),
-        ('https://api.ipify.org/?format=json', True, 'ip')]
+# - key: key of the IP address in the JSON structure
+urls = [
+    #  glances_ip.py plugin relies on low rating / malicious site domain #1975
+    # ('https://ip.42.pl/raw', False, None),
+    ('https://httpbin.org/ip', True, 'origin'),
+    ('https://api.ipify.org/?format=json', True, 'ip'),
+    ('https://ipv4.jsonip.com', True, 'ip'),
+]
 
 
 class Plugin(GlancesPlugin):
@@ -61,7 +64,7 @@ class Plugin(GlancesPlugin):
         self.display_curse = True
 
         # Get the public IP address once (not for each refresh)
-        if not self.is_disable() and not import_error_tag:
+        if not import_error_tag:
             self.public_address = PublicIpAddress().get()
 
     @GlancesPlugin._check_decorator
@@ -69,7 +72,7 @@ class Plugin(GlancesPlugin):
     def update(self):
         """Update IP stats using the input method.
 
-        Stats is dict
+        :return: the stats dict
         """
         # Init new stats
         stats = self.get_init_value()
@@ -103,7 +106,7 @@ class Plugin(GlancesPlugin):
         # Call the father's method
         super(Plugin, self).update_views()
 
-        # Add specifics informations
+        # Add specifics information
         # Optional
         for key in iterkeys(self.stats):
             self.views[key]['optional'] = True
@@ -114,7 +117,7 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist and display plugin enable...
-        if not self.stats or self.is_disable() or import_error_tag:
+        if not self.stats or self.is_disabled() or import_error_tag:
             return ret
 
         # Build the string message
@@ -150,6 +153,9 @@ class Plugin(GlancesPlugin):
         """
         # Thanks to @Atticfire
         # See https://github.com/nicolargo/glances/issues/1417#issuecomment-469894399
+        if ip is None:
+            # Correct issue #1528
+            return 0
         return sum(bin(int(x)).count('1') for x in ip.split('.'))
 
 
