@@ -20,25 +20,46 @@
 """Swap memory plugin."""
 
 from glances.compat import iterkeys
+from glances.timer import getTimeSinceLastUpdate
 from glances.plugins.glances_plugin import GlancesPlugin
 
 import psutil
 
+# Fields description
+fields_description = {
+    'total': {'description': 'Total swap memory.', 'unit': 'bytes', 'min_symbol': 'K'},
+    'used': {'description': 'Used swap memory.', 'unit': 'bytes', 'min_symbol': 'K'},
+    'free': {'description': 'Free swap memory.', 'unit': 'bytes', 'min_symbol': 'K'},
+    'percent': {'description': 'Used swap memory in percentage.', 'unit': 'percent'},
+    'sin': {
+        'description': 'The number of bytes the system has swapped in from disk (cumulative).',
+        'unit': 'bytes',
+        'min_symbol': 'K',
+    },
+    'sout': {
+        'description': 'The number of bytes the system has swapped out from disk (cumulative).',
+        'unit': 'bytes',
+        'min_symbol': 'K',
+    },
+    'time_since_update': {'description': 'Number of seconds since last update.', 'unit': 'seconds'},
+}
+
 # SNMP OID
 # Total Swap Size: .1.3.6.1.4.1.2021.4.3.0
 # Available Swap Space: .1.3.6.1.4.1.2021.4.4.0
-snmp_oid = {'default': {'total': '1.3.6.1.4.1.2021.4.3.0',
-                        'free': '1.3.6.1.4.1.2021.4.4.0'},
-            'windows': {'mnt_point': '1.3.6.1.2.1.25.2.3.1.3',
-                        'alloc_unit': '1.3.6.1.2.1.25.2.3.1.4',
-                        'size': '1.3.6.1.2.1.25.2.3.1.5',
-                        'used': '1.3.6.1.2.1.25.2.3.1.6'}}
+snmp_oid = {
+    'default': {'total': '1.3.6.1.4.1.2021.4.3.0', 'free': '1.3.6.1.4.1.2021.4.4.0'},
+    'windows': {
+        'mnt_point': '1.3.6.1.2.1.25.2.3.1.3',
+        'alloc_unit': '1.3.6.1.2.1.25.2.3.1.4',
+        'size': '1.3.6.1.2.1.25.2.3.1.5',
+        'used': '1.3.6.1.2.1.25.2.3.1.6',
+    },
+}
 
 # Define the history items list
 # All items in this list will be historised if the --enable-history tag is set
-items_history_list = [{'name': 'percent',
-                       'description': 'Swap memory usage',
-                       'y_unit': '%'}]
+items_history_list = [{'name': 'percent', 'description': 'Swap memory usage', 'y_unit': '%'}]
 
 
 class Plugin(GlancesPlugin):
@@ -49,9 +70,9 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None, config=None):
         """Init the plugin."""
-        super(Plugin, self).__init__(args=args,
-                                     config=config,
-                                     items_history_list=items_history_list)
+        super(Plugin, self).__init__(
+            args=args, config=config, items_history_list=items_history_list, fields_description=fields_description
+        )
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -78,19 +99,21 @@ class Plugin(GlancesPlugin):
                 # free: free swap memory in bytes
                 # percent: the percentage usage
                 # sin: the number of bytes the system has swapped in from disk (cumulative)
-                # sout: the number of bytes the system has swapped out from disk
-                # (cumulative)
-                for swap in ['total', 'used', 'free', 'percent',
-                             'sin', 'sout']:
+                # sout: the number of bytes the system has swapped out from disk (cumulative)
+                for swap in ['total', 'used', 'free', 'percent', 'sin', 'sout']:
                     if hasattr(sm_stats, swap):
                         stats[swap] = getattr(sm_stats, swap)
+
+                # By storing time data we enable sin/s and sout/s calculations in the
+                # XML/RPC API, which would otherwise be overly difficult work
+                # for users of the API
+                stats['time_since_update'] = getTimeSinceLastUpdate('memswap')
         elif self.input_method == 'snmp':
             # Update stats using SNMP
             if self.short_system_name == 'windows':
                 # Mem stats for Windows OS are stored in the FS table
                 try:
-                    fs_stat = self.get_stats_snmp(snmp_oid=snmp_oid[self.short_system_name],
-                                                  bulk=True)
+                    fs_stat = self.get_stats_snmp(snmp_oid=snmp_oid[self.short_system_name], bulk=True)
                 except KeyError:
                     self.reset()
                 else:
@@ -100,12 +123,9 @@ class Plugin(GlancesPlugin):
                         # thus to run more programs by swapping unused memory
                         # zone (page) to a disk file.
                         if fs == 'Virtual Memory':
-                            stats['total'] = int(
-                                fs_stat[fs]['size']) * int(fs_stat[fs]['alloc_unit'])
-                            stats['used'] = int(
-                                fs_stat[fs]['used']) * int(fs_stat[fs]['alloc_unit'])
-                            stats['percent'] = float(
-                                stats['used'] * 100 / stats['total'])
+                            stats['total'] = int(fs_stat[fs]['size']) * int(fs_stat[fs]['alloc_unit'])
+                            stats['used'] = int(fs_stat[fs]['used']) * int(fs_stat[fs]['alloc_unit'])
+                            stats['percent'] = float(stats['used'] * 100 / stats['total'])
                             stats['free'] = stats['total'] - stats['used']
                             break
             else:
@@ -124,8 +144,7 @@ class Plugin(GlancesPlugin):
 
                 # percent: the percentage usage calculated as (total -
                 # available) / total * 100.
-                stats['percent'] = float(
-                    (stats['total'] - stats['free']) / stats['total'] * 100)
+                stats['percent'] = float((stats['total'] - stats['free']) / stats['total'] * 100)
 
         # Update the stats
         self.stats = stats
@@ -137,7 +156,7 @@ class Plugin(GlancesPlugin):
         # Call the father's method
         super(Plugin, self).update_views()
 
-        # Add specifics informations
+        # Add specifics information
         # Alert and log
         if 'used' in self.stats and 'total' in self.stats and 'percent' in self.stats:
             self.views['percent']['decoration'] = self.get_alert_log(self.stats['used'], maximum=self.stats['total'])
@@ -148,40 +167,35 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist and plugin not disabled
-        if not self.stats or self.is_disable():
+        if not self.stats or self.is_disabled():
             return ret
 
-        # Build the string message
-        # Header
+        # First line
+        # total%
         msg = '{}'.format('SWAP')
         ret.append(self.curse_add_line(msg, "TITLE"))
         msg = ' {:3}'.format(self.trend_msg(self.get_trend('percent')))
         ret.append(self.curse_add_line(msg))
         # Percent memory usage
         msg = '{:>6.1%}'.format(self.stats['percent'] / 100)
-        ret.append(self.curse_add_line(
-            msg, self.get_views(key='percent', option='decoration')))
-        # New line
+        ret.append(self.curse_add_line(msg, self.get_views(key='percent', option='decoration')))
+
+        # Second line
+        # total
         ret.append(self.curse_new_line())
         # Total memory usage
-        msg = '{:8}'.format('total:')
-        ret.append(self.curse_add_line(msg))
-        msg = '{:>6}'.format(self.auto_unit(self.stats['total']))
-        ret.append(self.curse_add_line(msg))
-        # New line
+        ret.extend(self.curse_add_stat('total', width=16))
+
+        # Third line
+        # used
         ret.append(self.curse_new_line())
         # Used memory usage
-        msg = '{:8}'.format('used:')
-        ret.append(self.curse_add_line(msg))
-        msg = '{:>6}'.format(self.auto_unit(self.stats['used']))
-        ret.append(self.curse_add_line(
-            msg, self.get_views(key='used', option='decoration')))
-        # New line
+        ret.extend(self.curse_add_stat('used', width=16))
+
+        # Fourth line
+        # free
         ret.append(self.curse_new_line())
         # Free memory usage
-        msg = '{:8}'.format('free:')
-        ret.append(self.curse_add_line(msg))
-        msg = '{:>6}'.format(self.auto_unit(self.stats['free']))
-        ret.append(self.curse_add_line(msg))
+        ret.extend(self.curse_add_stat('free', width=16))
 
         return ret
